@@ -20,7 +20,11 @@ class DisFlood:
         Messages = []
         for i in range(0,self.CountMessages):
             for ii in range(0,self.CountMessagesForInterval):
+                if len(Messages) > self.CountMessages - 1:
+                    return
                 Messages.append(self.Client.send_message(self.ChannelId,Content,ReturnMessages)) 
+            if len(Messages) > self.CountMessages - 1:
+                    return
             time.sleep(self.Interval)
         return Messages
         
